This directory contains several files that specify the versions of
our dependencies used in our CI workflows. *Landlab* does not require
these exact version numbers to work properly, these are what we
test against to ensure that things don't break as new versions
of our dependencies are released.

## Managed by dependabot

All files with a `.txt` extension are managed by dependabot and **should
not be manually edited** unless you need to add or remove a dependency.
